# Quicklogic Boards

The {py:mod}`torii_boards.quicklogic` module provides a collection of QuickLogic FPGA development boards, they are based off the Torii {py:class}`QuicklogicPlatform <torii.platform.vendor.quicklogic.QuicklogicPlatform>` platform and support the [Symbiflow] toolchain.

```{toctree}
:maxdepth: 2
eos_s3
```

[Symbiflow]: https://github.com/QuickLogic-Corp/quicklogic-fpga-toolchain
